@@ -89,20 +89,22 @@ class Certificate:
     @classmethod
     def from_file(cls, path: t.Union[str, Path]) -> Certificate:
         """Parse a certificate"""
-        ca_file = Path(path).expanduser()
+        cert_file = Path(path).expanduser()
+        if not cert_file.exists():
+            raise FileNotFoundError(cert_file.as_posix())
         output = check_output(
-            ["nebula-cert", "print", "-path", ca_file.as_posix(), "-json"]
+            ["nebula-cert", "print", "-path", cert_file.as_posix(), "-json"]
         ).strip()
-        return cls(**json.loads(output), raw=ca_file.read_bytes())
+        return cls(**json.loads(output), raw=cert_file.read_bytes())
 
     @classmethod
     def from_bytes(cls, data: bytes) -> Certificate:
         """Parse a certificate"""
         with tempfile.TemporaryDirectory() as tmpdir:
-            ca_file = Path(tmpdir, "ca.crt")
-            ca_file.write_bytes(data)
+            cert_file = Path(tmpdir, "crt")
+            cert_file.write_bytes(data)
             output = check_output(
-                ["nebula-cert", "print", "-path", ca_file.as_posix(), "-json"]
+                ["nebula-cert", "print", "-path", cert_file.as_posix(), "-json"]
             ).strip()
             return cls(**json.loads(output), raw=data)
 
